@@ -11,17 +11,17 @@ sub new {
     return $self;
 }
 
-sub DummmyMethodForTestOverriding {
+sub DummyMethodForTestOverriding {
     my $self = shift;
-    return 'A dummmy method';
+    return 'A dummy method';
 }
 
-sub secondDummmyMethodForTestOverriding {
+sub secondDummyMethodForTestOverriding {
     my $self = shift;
-    return 'A second dummmy method';
+    return 'A second dummy method';
 }
 
-sub dummmyMethodWithParameterReturn {
+sub dummyMethodWithParameterReturn {
     my $self = shift;
     my ( $Parameter ) = @_;
     return $Parameter;
